package cn.ibizlab.api.rest;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;

import lombok.extern.slf4j.Slf4j;
import com.alibaba.fastjson.JSONObject;

import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.security.access.prepost.PreAuthorize;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import cn.ibizlab.api.dto.*;
import cn.ibizlab.api.mapping.*;
import cn.ibizlab.core.workflow.domain.WFMember;
import cn.ibizlab.core.workflow.service.IWFMemberService;
import cn.ibizlab.core.workflow.filter.WFMemberSearchContext;




@Slf4j
@Api(tags = {"WFMember" })
@RestController("api-wfmember")
@RequestMapping("")
public class WFMemberResource {

    @Autowired
    private IWFMemberService wfmemberService;

    @Autowired
    @Lazy
    private WFMemberMapping wfmemberMapping;




    @ApiOperation(value = "CheckKey", tags = {"WFMember" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/wfmembers/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody WFMemberDTO wfmemberdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(wfmemberService.checkKey(wfmemberMapping.toDomain(wfmemberdto)));
    }




    @ApiOperation(value = "GetDraft", tags = {"WFMember" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/wfmembers/getdraft")
    public ResponseEntity<WFMemberDTO> getDraft() {
        return ResponseEntity.status(HttpStatus.OK).body(wfmemberMapping.toDto(wfmemberService.getDraft(new WFMember())));
    }




    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','ibzwf-WFMember-Create-all')")
    @ApiOperation(value = "Create", tags = {"WFMember" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/wfmembers")
    @Transactional
    public ResponseEntity<WFMemberDTO> create(@RequestBody WFMemberDTO wfmemberdto) {
        WFMember domain = wfmemberMapping.toDomain(wfmemberdto);
		wfmemberService.create(domain);
        WFMemberDTO dto = wfmemberMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }
    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','ibzwf-WFMember-Create-all')")
    @ApiOperation(value = "createBatch", tags = {"WFMember" },  notes = "createBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/wfmembers/batch")
    public ResponseEntity<Boolean> createBatch(@RequestBody List<WFMemberDTO> wfmemberdtos) {
        wfmemberService.createBatch(wfmemberMapping.toDomain(wfmemberdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','ibzwf-WFMember-Remove-all')")
    @ApiOperation(value = "Remove", tags = {"WFMember" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/wfmembers/{wfmember_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("wfmember_id") String wfmember_id) {
         return ResponseEntity.status(HttpStatus.OK).body(wfmemberService.remove(wfmember_id));
    }

    @ApiOperation(value = "RemoveBatch", tags = {"WFMember" },  notes = "RemoveBatch")
	@RequestMapping(method = RequestMethod.DELETE, value = "/wfmembers/batch")
    public ResponseEntity<Boolean> removeBatch(@RequestBody List<String> ids) {
        wfmemberService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @ApiOperation(value = "Save", tags = {"WFMember" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/wfmembers/save")
    public ResponseEntity<Boolean> save(@RequestBody WFMemberDTO wfmemberdto) {
        return ResponseEntity.status(HttpStatus.OK).body(wfmemberService.save(wfmemberMapping.toDomain(wfmemberdto)));
    }

    @ApiOperation(value = "SaveBatch", tags = {"WFMember" },  notes = "SaveBatch")
	@RequestMapping(method = RequestMethod.POST, value = "/wfmembers/savebatch")
    public ResponseEntity<Boolean> saveBatch(@RequestBody List<WFMemberDTO> wfmemberdtos) {
        wfmemberService.saveBatch(wfmemberMapping.toDomain(wfmemberdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','ibzwf-WFMember-Update-all')")
    @ApiOperation(value = "Update", tags = {"WFMember" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/wfmembers/{wfmember_id}")
    @Transactional
    public ResponseEntity<WFMemberDTO> update(@PathVariable("wfmember_id") String wfmember_id, @RequestBody WFMemberDTO wfmemberdto) {
		WFMember domain = wfmemberMapping.toDomain(wfmemberdto);
        domain.setMemberid(wfmember_id);
		wfmemberService.update(domain);
		WFMemberDTO dto = wfmemberMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','ibzwf-WFMember-Update-all')")
    @ApiOperation(value = "UpdateBatch", tags = {"WFMember" },  notes = "UpdateBatch")
	@RequestMapping(method = RequestMethod.PUT, value = "/wfmembers/batch")
    public ResponseEntity<Boolean> updateBatch(@RequestBody List<WFMemberDTO> wfmemberdtos) {
        wfmemberService.updateBatch(wfmemberMapping.toDomain(wfmemberdtos));
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }




    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','ibzwf-WFMember-Get-all')")
    @ApiOperation(value = "Get", tags = {"WFMember" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/wfmembers/{wfmember_id}")
    public ResponseEntity<WFMemberDTO> get(@PathVariable("wfmember_id") String wfmember_id) {
        WFMember domain = wfmemberService.get(wfmember_id);
        WFMemberDTO dto = wfmemberMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','ibzwf-WFMember-Default-all')")
	@ApiOperation(value = "fetchDEFAULT", tags = {"WFMember" } ,notes = "fetchDEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/wfmembers/fetchdefault")
	public ResponseEntity<List<WFMemberDTO>> fetchDefault(WFMemberSearchContext context) {
        Page<WFMember> domains = wfmemberService.searchDefault(context) ;
        List<WFMemberDTO> list = wfmemberMapping.toDto(domains.getContent());
        return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

    @PreAuthorize("hasAnyAuthority('ROLE_SUPERADMIN','ibzwf-WFMember-Default-all')")
	@ApiOperation(value = "searchDEFAULT", tags = {"WFMember" } ,notes = "searchDEFAULT")
    @RequestMapping(method= RequestMethod.POST , value="/wfmembers/searchdefault")
	public ResponseEntity<Page<WFMemberDTO>> searchDefault(@RequestBody WFMemberSearchContext context) {
        Page<WFMember> domains = wfmemberService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(wfmemberMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "CheckKeyByWFGroup", tags = {"WFMember" },  notes = "CheckKeyByWFGroup")
	@RequestMapping(method = RequestMethod.POST, value = "/wfgroups/{wfgroup_id}/wfmembers/checkkey")
    public ResponseEntity<Boolean> checkKeyByWFGroup(@PathVariable("wfgroup_id") String wfgroup_id, @RequestBody WFMemberDTO wfmemberdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(wfmemberService.checkKey(wfmemberMapping.toDomain(wfmemberdto)));
    }

    @ApiOperation(value = "GetDraftByWFGroup", tags = {"WFMember" },  notes = "GetDraftByWFGroup")
    @RequestMapping(method = RequestMethod.GET, value = "/wfgroups/{wfgroup_id}/wfmembers/getdraft")
    public ResponseEntity<WFMemberDTO> getDraftByWFGroup(@PathVariable("wfgroup_id") String wfgroup_id) {
        WFMember domain = new WFMember();
        domain.setGroupid(wfgroup_id);
        return ResponseEntity.status(HttpStatus.OK).body(wfmemberMapping.toDto(wfmemberService.getDraft(domain)));
    }

    @ApiOperation(value = "CreateByWFGroup", tags = {"WFMember" },  notes = "CreateByWFGroup")
	@RequestMapping(method = RequestMethod.POST, value = "/wfgroups/{wfgroup_id}/wfmembers")
    @Transactional
    public ResponseEntity<WFMemberDTO> createByWFGroup(@PathVariable("wfgroup_id") String wfgroup_id, @RequestBody WFMemberDTO wfmemberdto) {
        WFMember domain = wfmemberMapping.toDomain(wfmemberdto);
        domain.setGroupid(wfgroup_id);
		wfmemberService.create(domain);
        WFMemberDTO dto = wfmemberMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByWFGroup", tags = {"WFMember" },  notes = "createBatchByWFGroup")
	@RequestMapping(method = RequestMethod.POST, value = "/wfgroups/{wfgroup_id}/wfmembers/batch")
    public ResponseEntity<Boolean> createBatchByWFGroup(@PathVariable("wfgroup_id") String wfgroup_id, @RequestBody List<WFMemberDTO> wfmemberdtos) {
        List<WFMember> domainlist=wfmemberMapping.toDomain(wfmemberdtos);
        for(WFMember domain:domainlist){
            domain.setGroupid(wfgroup_id);
        }
        wfmemberService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "RemoveByWFGroup", tags = {"WFMember" },  notes = "RemoveByWFGroup")
	@RequestMapping(method = RequestMethod.DELETE, value = "/wfgroups/{wfgroup_id}/wfmembers/{wfmember_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByWFGroup(@PathVariable("wfgroup_id") String wfgroup_id, @PathVariable("wfmember_id") String wfmember_id) {
		return ResponseEntity.status(HttpStatus.OK).body(wfmemberService.remove(wfmember_id));
    }

    @ApiOperation(value = "RemoveBatchByWFGroup", tags = {"WFMember" },  notes = "RemoveBatchByWFGroup")
	@RequestMapping(method = RequestMethod.DELETE, value = "/wfgroups/{wfgroup_id}/wfmembers/batch")
    public ResponseEntity<Boolean> removeBatchByWFGroup(@RequestBody List<String> ids) {
        wfmemberService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "SaveByWFGroup", tags = {"WFMember" },  notes = "SaveByWFGroup")
	@RequestMapping(method = RequestMethod.POST, value = "/wfgroups/{wfgroup_id}/wfmembers/save")
    public ResponseEntity<Boolean> saveByWFGroup(@PathVariable("wfgroup_id") String wfgroup_id, @RequestBody WFMemberDTO wfmemberdto) {
        WFMember domain = wfmemberMapping.toDomain(wfmemberdto);
        domain.setGroupid(wfgroup_id);
        return ResponseEntity.status(HttpStatus.OK).body(wfmemberService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByWFGroup", tags = {"WFMember" },  notes = "SaveBatchByWFGroup")
	@RequestMapping(method = RequestMethod.POST, value = "/wfgroups/{wfgroup_id}/wfmembers/savebatch")
    public ResponseEntity<Boolean> saveBatchByWFGroup(@PathVariable("wfgroup_id") String wfgroup_id, @RequestBody List<WFMemberDTO> wfmemberdtos) {
        List<WFMember> domainlist=wfmemberMapping.toDomain(wfmemberdtos);
        for(WFMember domain:domainlist){
             domain.setGroupid(wfgroup_id);
        }
        wfmemberService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByWFGroup", tags = {"WFMember" },  notes = "UpdateByWFGroup")
	@RequestMapping(method = RequestMethod.PUT, value = "/wfgroups/{wfgroup_id}/wfmembers/{wfmember_id}")
    @Transactional
    public ResponseEntity<WFMemberDTO> updateByWFGroup(@PathVariable("wfgroup_id") String wfgroup_id, @PathVariable("wfmember_id") String wfmember_id, @RequestBody WFMemberDTO wfmemberdto) {
        WFMember domain = wfmemberMapping.toDomain(wfmemberdto);
        domain.setGroupid(wfgroup_id);
        domain.setMemberid(wfmember_id);
		wfmemberService.update(domain);
        WFMemberDTO dto = wfmemberMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByWFGroup", tags = {"WFMember" },  notes = "UpdateBatchByWFGroup")
	@RequestMapping(method = RequestMethod.PUT, value = "/wfgroups/{wfgroup_id}/wfmembers/batch")
    public ResponseEntity<Boolean> updateBatchByWFGroup(@PathVariable("wfgroup_id") String wfgroup_id, @RequestBody List<WFMemberDTO> wfmemberdtos) {
        List<WFMember> domainlist=wfmemberMapping.toDomain(wfmemberdtos);
        for(WFMember domain:domainlist){
            domain.setGroupid(wfgroup_id);
        }
        wfmemberService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByWFGroup", tags = {"WFMember" },  notes = "GetByWFGroup")
	@RequestMapping(method = RequestMethod.GET, value = "/wfgroups/{wfgroup_id}/wfmembers/{wfmember_id}")
    public ResponseEntity<WFMemberDTO> getByWFGroup(@PathVariable("wfgroup_id") String wfgroup_id, @PathVariable("wfmember_id") String wfmember_id) {
        WFMember domain = wfmemberService.get(wfmember_id);
        WFMemberDTO dto = wfmemberMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

	@ApiOperation(value = "fetchDEFAULTByWFGroup", tags = {"WFMember" } ,notes = "fetchDEFAULTByWFGroup")
    @RequestMapping(method= RequestMethod.GET , value="/wfgroups/{wfgroup_id}/wfmembers/fetchdefault")
	public ResponseEntity<List<WFMemberDTO>> fetchWFMemberDefaultByWFGroup(@PathVariable("wfgroup_id") String wfgroup_id,WFMemberSearchContext context) {
        context.setN_groupid_eq(wfgroup_id);
        Page<WFMember> domains = wfmemberService.searchDefault(context) ;
        List<WFMemberDTO> list = wfmemberMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByWFGroup", tags = {"WFMember" } ,notes = "searchDEFAULTByWFGroup")
    @RequestMapping(method= RequestMethod.POST , value="/wfgroups/{wfgroup_id}/wfmembers/searchdefault")
	public ResponseEntity<Page<WFMemberDTO>> searchWFMemberDefaultByWFGroup(@PathVariable("wfgroup_id") String wfgroup_id, @RequestBody WFMemberSearchContext context) {
        context.setN_groupid_eq(wfgroup_id);
        Page<WFMember> domains = wfmemberService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(wfmemberMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}



    @ApiOperation(value = "CheckKeyByWFUser", tags = {"WFMember" },  notes = "CheckKeyByWFUser")
	@RequestMapping(method = RequestMethod.POST, value = "/wfusers/{wfuser_id}/wfmembers/checkkey")
    public ResponseEntity<Boolean> checkKeyByWFUser(@PathVariable("wfuser_id") String wfuser_id, @RequestBody WFMemberDTO wfmemberdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(wfmemberService.checkKey(wfmemberMapping.toDomain(wfmemberdto)));
    }

    @ApiOperation(value = "GetDraftByWFUser", tags = {"WFMember" },  notes = "GetDraftByWFUser")
    @RequestMapping(method = RequestMethod.GET, value = "/wfusers/{wfuser_id}/wfmembers/getdraft")
    public ResponseEntity<WFMemberDTO> getDraftByWFUser(@PathVariable("wfuser_id") String wfuser_id) {
        WFMember domain = new WFMember();
        domain.setUserid(wfuser_id);
        return ResponseEntity.status(HttpStatus.OK).body(wfmemberMapping.toDto(wfmemberService.getDraft(domain)));
    }

    @ApiOperation(value = "CreateByWFUser", tags = {"WFMember" },  notes = "CreateByWFUser")
	@RequestMapping(method = RequestMethod.POST, value = "/wfusers/{wfuser_id}/wfmembers")
    @Transactional
    public ResponseEntity<WFMemberDTO> createByWFUser(@PathVariable("wfuser_id") String wfuser_id, @RequestBody WFMemberDTO wfmemberdto) {
        WFMember domain = wfmemberMapping.toDomain(wfmemberdto);
        domain.setUserid(wfuser_id);
		wfmemberService.create(domain);
        WFMemberDTO dto = wfmemberMapping.toDto(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "createBatchByWFUser", tags = {"WFMember" },  notes = "createBatchByWFUser")
	@RequestMapping(method = RequestMethod.POST, value = "/wfusers/{wfuser_id}/wfmembers/batch")
    public ResponseEntity<Boolean> createBatchByWFUser(@PathVariable("wfuser_id") String wfuser_id, @RequestBody List<WFMemberDTO> wfmemberdtos) {
        List<WFMember> domainlist=wfmemberMapping.toDomain(wfmemberdtos);
        for(WFMember domain:domainlist){
            domain.setUserid(wfuser_id);
        }
        wfmemberService.createBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "RemoveByWFUser", tags = {"WFMember" },  notes = "RemoveByWFUser")
	@RequestMapping(method = RequestMethod.DELETE, value = "/wfusers/{wfuser_id}/wfmembers/{wfmember_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByWFUser(@PathVariable("wfuser_id") String wfuser_id, @PathVariable("wfmember_id") String wfmember_id) {
		return ResponseEntity.status(HttpStatus.OK).body(wfmemberService.remove(wfmember_id));
    }

    @ApiOperation(value = "RemoveBatchByWFUser", tags = {"WFMember" },  notes = "RemoveBatchByWFUser")
	@RequestMapping(method = RequestMethod.DELETE, value = "/wfusers/{wfuser_id}/wfmembers/batch")
    public ResponseEntity<Boolean> removeBatchByWFUser(@RequestBody List<String> ids) {
        wfmemberService.removeBatch(ids);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "SaveByWFUser", tags = {"WFMember" },  notes = "SaveByWFUser")
	@RequestMapping(method = RequestMethod.POST, value = "/wfusers/{wfuser_id}/wfmembers/save")
    public ResponseEntity<Boolean> saveByWFUser(@PathVariable("wfuser_id") String wfuser_id, @RequestBody WFMemberDTO wfmemberdto) {
        WFMember domain = wfmemberMapping.toDomain(wfmemberdto);
        domain.setUserid(wfuser_id);
        return ResponseEntity.status(HttpStatus.OK).body(wfmemberService.save(domain));
    }

    @ApiOperation(value = "SaveBatchByWFUser", tags = {"WFMember" },  notes = "SaveBatchByWFUser")
	@RequestMapping(method = RequestMethod.POST, value = "/wfusers/{wfuser_id}/wfmembers/savebatch")
    public ResponseEntity<Boolean> saveBatchByWFUser(@PathVariable("wfuser_id") String wfuser_id, @RequestBody List<WFMemberDTO> wfmemberdtos) {
        List<WFMember> domainlist=wfmemberMapping.toDomain(wfmemberdtos);
        for(WFMember domain:domainlist){
             domain.setUserid(wfuser_id);
        }
        wfmemberService.saveBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "UpdateByWFUser", tags = {"WFMember" },  notes = "UpdateByWFUser")
	@RequestMapping(method = RequestMethod.PUT, value = "/wfusers/{wfuser_id}/wfmembers/{wfmember_id}")
    @Transactional
    public ResponseEntity<WFMemberDTO> updateByWFUser(@PathVariable("wfuser_id") String wfuser_id, @PathVariable("wfmember_id") String wfmember_id, @RequestBody WFMemberDTO wfmemberdto) {
        WFMember domain = wfmemberMapping.toDomain(wfmemberdto);
        domain.setUserid(wfuser_id);
        domain.setMemberid(wfmember_id);
		wfmemberService.update(domain);
        WFMemberDTO dto = wfmemberMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "UpdateBatchByWFUser", tags = {"WFMember" },  notes = "UpdateBatchByWFUser")
	@RequestMapping(method = RequestMethod.PUT, value = "/wfusers/{wfuser_id}/wfmembers/batch")
    public ResponseEntity<Boolean> updateBatchByWFUser(@PathVariable("wfuser_id") String wfuser_id, @RequestBody List<WFMemberDTO> wfmemberdtos) {
        List<WFMember> domainlist=wfmemberMapping.toDomain(wfmemberdtos);
        for(WFMember domain:domainlist){
            domain.setUserid(wfuser_id);
        }
        wfmemberService.updateBatch(domainlist);
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetByWFUser", tags = {"WFMember" },  notes = "GetByWFUser")
	@RequestMapping(method = RequestMethod.GET, value = "/wfusers/{wfuser_id}/wfmembers/{wfmember_id}")
    public ResponseEntity<WFMemberDTO> getByWFUser(@PathVariable("wfuser_id") String wfuser_id, @PathVariable("wfmember_id") String wfmember_id) {
        WFMember domain = wfmemberService.get(wfmember_id);
        WFMemberDTO dto = wfmemberMapping.toDto(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

	@ApiOperation(value = "fetchDEFAULTByWFUser", tags = {"WFMember" } ,notes = "fetchDEFAULTByWFUser")
    @RequestMapping(method= RequestMethod.GET , value="/wfusers/{wfuser_id}/wfmembers/fetchdefault")
	public ResponseEntity<List<WFMemberDTO>> fetchWFMemberDefaultByWFUser(@PathVariable("wfuser_id") String wfuser_id,WFMemberSearchContext context) {
        context.setN_userid_eq(wfuser_id);
        Page<WFMember> domains = wfmemberService.searchDefault(context) ;
        List<WFMemberDTO> list = wfmemberMapping.toDto(domains.getContent());
	    return ResponseEntity.status(HttpStatus.OK)
                .header("x-page", String.valueOf(context.getPageable().getPageNumber()))
                .header("x-per-page", String.valueOf(context.getPageable().getPageSize()))
                .header("x-total", String.valueOf(domains.getTotalElements()))
                .body(list);
	}

	@ApiOperation(value = "searchDEFAULTByWFUser", tags = {"WFMember" } ,notes = "searchDEFAULTByWFUser")
    @RequestMapping(method= RequestMethod.POST , value="/wfusers/{wfuser_id}/wfmembers/searchdefault")
	public ResponseEntity<Page<WFMemberDTO>> searchWFMemberDefaultByWFUser(@PathVariable("wfuser_id") String wfuser_id, @RequestBody WFMemberSearchContext context) {
        context.setN_userid_eq(wfuser_id);
        Page<WFMember> domains = wfmemberService.searchDefault(context) ;
	    return ResponseEntity.status(HttpStatus.OK)
                .body(new PageImpl(wfmemberMapping.toDto(domains.getContent()), context.getPageable(), domains.getTotalElements()));
	}


    /**
     * 用户权限校验
     * @return
     */
	public WFMember getEntity(){
        return new WFMember();
    }

}
